# hatch build

A minimal CLI wrapper around hatchling build

[![Build Status](https://github.com/python-project-templates/hatch-build/actions/workflows/build.yaml/badge.svg?branch=main&event=push)](https://github.com/python-project-templates/hatch-build/actions/workflows/build.yaml)
[![codecov](https://codecov.io/gh/python-project-templates/hatch-build/branch/main/graph/badge.svg)](https://codecov.io/gh/python-project-templates/hatch-build)
[![License](https://img.shields.io/github/license/python-project-templates/hatch-build)](https://github.com/python-project-templates/hatch-build)
[![PyPI](https://img.shields.io/pypi/v/hatch-build.svg)](https://pypi.python.org/pypi/hatch-build)

## Overview

This library provides a minimal CLI `hatch-build`, equivalent to [`hatchling build`](https://hatch.pypa.io/latest/) except for [the enablement of passthrough arguments](https://github.com/pypa/hatch/pull/1743).

```bash
hatch-build -- --my-custom-plugin-arg
```

> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
